@@ -3,7 +3,7 @@
  * Parser interface compatible with the old (bison/flex based) parser. */
 
 /*
- *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2016 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ static symtab make_symtab(const ex& l);
 
 ptr<basic> ex::construct_from_string_and_lst(const std::string &s, const ex &l)
 {
-	static const bool strict = true;
+	constexpr bool strict = true;
 	symtab syms = make_symtab(l);
 	parser reader(syms, strict); 
 	ex parsed_ex = reader(s);
